@@ -5,7 +5,7 @@
 # integrations.py
 # Classes related to Integrations.
 #
-# (c) Copyright 2019 Hewlett Packard Enterprise Development LP
+# (c) Copyright 2019-2020 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -28,6 +28,7 @@ POST install/{intgld} e.g. CUSTOM
 
 GET installed/search?queryString=
 GET installed/{installedIntgld}
+GET installed/{installedIntgld}/configFile/kubernetes
 DELETE installed/{installedIntgld}
 POST installed/{installedIntgld}
 POST installed/{installedIntgld}/notifier
@@ -68,7 +69,7 @@ class Types(ApiWrapper):
         super(Types, self).__init__(parent.api, 'available')
 
     def search(self, pattern=''):
-        suffix = '/search'
+        suffix = 'search'
         if pattern:
             suffix += '?' + pattern
         return self.api.get(suffix)
@@ -83,11 +84,14 @@ class Instances(ApiWrapper):
         self.creator_api.chroot('install')
 
     def search(self, pattern=''):
-        suffix = '/search'
+        suffix = 'search'
         if pattern:
             suffix += '?' + pattern
         return self.api.get(suffix)
 
+    def get_kubernetes_configuration(self, uuid):
+        return self.api.get('%s/configFile/kubernetes' % uuid)
+
     def create(self, type_name, definition):
         resp = self.creator_api.post(type_name, json=definition)
         return resp
