@@ -33,6 +33,8 @@ import opsramp.mgmt_profiles
 import opsramp.sites
 import opsramp.service_maps
 import opsramp.kb
+import opsramp.resources
+import opsramp.first_response
 
 
 class Tenant(ApiWrapper):
@@ -70,6 +72,9 @@ class Tenant(ApiWrapper):
     def credential_sets(self):
         return opsramp.devmgmt.CredentialSets(self)
 
+    def resources(self):
+        return opsramp.resources.Resources(self)
+
     def roles(self):
         return opsramp.roles.Roles(self)
 
@@ -90,3 +95,6 @@ class Tenant(ApiWrapper):
 
     def kb(self):
         return opsramp.kb.KnowledgeBase(self)
+
+    def first_response(self):
+        return opsramp.first_response.First_Response(self)
